==> samxode_ip-0.1.7.tar.gz: samxode_ip-0.1.7/samxode_ip/main.py <==
import pyfiglet
import time
import os
import random
from colorama import Fore, Style
import threading

#def clear_terminal():
 #   """Membersihkan layar terminal (Windows & Linux/macOS)."""
    #os.system("cls" if os.name == "nt" else "clear")

def print_static_text():
    """Menampilkan teks tambahan yang tidak berubah."""
    print("\n" + Fore.GREEN + "🔥 Stay Connected! 🔥" + Style.RESET_ALL)
    print(Fore.CYAN + "📢 Join Telegram Group: https://t.me/sam_xode" + Style.RESET_ALL)
    print(Fore.GREEN + "🐦 Follow Twitter: https://x.com/sam_xode" + Style.RESET_ALL)
    print(Fore.GREEN + "PRESS CTRL + C TO CONTINUE" + Style.RESET_ALL)

def get_random_color():
    """Mengembalikan warna acak dari colorama."""
    colors = [Fore.RED, Fore.BLUE, Fore.YELLOW, Fore.MAGENTA, Fore.CYAN, Fore.GREEN, Fore.WHITE]
    return random.choice(colors)

def color_change_effect_forever(text="<SAMXODE/>", font="big", delay=3):
    """Menampilkan teks dengan warna berubah-ubah setiap beberapa detik."""
    ascii_art = pyfiglet.figlet_format(text, font=font)  
    try:
        while True:
            color = get_random_color()
            print(color + ascii_art + Style.RESET_ALL)
            print_static_text()
            time.sleep(delay)
    except KeyboardInterrupt:
        print(Fore.RED + "Color effect stopped!" + Style.RESET_ALL)


def start_watermark():
    """Menjalankan efek watermark di thread terpisah."""
    thread = threading.Thread(target=color_change_effect_forever, daemon=True)
    thread.start()
    
def start_samxode():
    print("Samxode watermark is active!")

==> samxode_ip-0.1.8.tar.gz: samxode_ip-0.1.8/samxode_ip/main.py <==
import pyfiglet
import time
import os
import random
from colorama import Fore, Style
import threading

#def clear_terminal():
 #   """Membersihkan layar terminal (Windows & Linux/macOS)."""
    #os.system("cls" if os.name == "nt" else "clear")

def print_static_text():
    """Menampilkan teks tambahan yang tidak berubah."""
    print("\n" + Fore.GREEN + "🔥 Stay Connected! 🔥" + Style.RESET_ALL)
    print(Fore.CYAN + "📢 Join Telegram Group: https://t.me/sam_xode" + Style.RESET_ALL)
    print(Fore.GREEN + "🐦 Follow Twitter: https://x.com/sam_xode" + Style.RESET_ALL)
    print(Fore.GREEN + "PRESS CTRL + C TO CONTINUE" + Style.RESET_ALL)

def get_random_color():
    """Mengembalikan warna acak dari colorama."""
    colors = [Fore.RED, Fore.BLUE, Fore.YELLOW, Fore.MAGENTA, Fore.CYAN, Fore.GREEN, Fore.WHITE]
    return random.choice(colors)

def color_change_effect_forever(text="<SAMXODE/>", font="big", delay=3):
    """Menampilkan teks dengan warna berubah-ubah setiap beberapa detik."""
    ascii_art = pyfiglet.figlet_format(text, font=font)  
    try:
        while True:
            color = get_random_color()
            print(color + ascii_art + Style.RESET_ALL)
            print_static_text()
            time.sleep(delay)
    except KeyboardInterrupt:
        print(Fore.RED + "Color effect stopped!" + Style.RESET_ALL)

def wave_effect(text="<SAMXODE/>", font="big", delay=0.2):
    """Menampilkan teks dengan efek gelombang warna."""
    ascii_art_lines = pyfiglet.figlet_format(text, font=font).split("\n")  
    colors = [Fore.RED, Fore.YELLOW, Fore.GREEN, Fore.CYAN, Fore.BLUE, Fore.MAGENTA]

    try:
        while True:
            for i in range(len(colors)):
                print("\n".join(
                    colors[(i + j) % len(colors)] + line + Style.RESET_ALL
                    for j, line in enumerate(ascii_art_lines)
                ))
                print_static_text()
                time.sleep(delay)
                os.system("cls" if os.name == "nt" else "clear")  # Bisa dihapus kalau tidak ingin layar bersih setiap iterasi
    except KeyboardInterrupt:
        print(Fore.RED + "Wave effect stopped!" + Style.RESET_ALL)


def start_watermark():
    """Menjalankan efek watermark dengan efek gelombang."""
    thread = threading.Thread(target=wave_effect, daemon=True)
    thread.start()
    
def start_samxode():
    print("Samxode watermark is active!")
